/// <reference types="react" />
import { AutoPosition, Options as AutoPositionOptions } from './useAutoPosition';
declare type Role = 'dialog' | 'alertdialog' | 'tooltip' | 'menu' | 'listbox' | 'grid' | 'tree';
declare const DefaultHoverConfig: {
    enabled: boolean | undefined;
    delay: number | Partial<{
        open: number;
        close: number;
    }> | null;
    interactive: boolean;
};
/**
 * Open the floating object on trigger hover.
 * * delay: Delay of the opening and closing. Default: 0
 * * interactive: Is tooltip interactive. Should not close if receiving hover. Default: Enabled
 */
declare type HoverConfig = Partial<typeof DefaultHoverConfig> | null | false;
declare const DefaultRoleConfig: {
    enabled: boolean;
    role: Role | null;
};
/**
 *  Add a11y parameters to a floating object automatically based on the role
 *  Default: Disabled
 */
declare type RoleConfig = Partial<typeof DefaultRoleConfig> | null | false;
declare const DefaultClickConfig: {
    enabled: boolean;
};
/**
 *  Auto open on click.
 *  Default: Disabled
 */
declare type ClickConfig = Partial<typeof DefaultClickConfig> | null | false;
declare const DefaultFocusConfig: {
    enabled: boolean;
};
/**
 *  Auto open on focus.
 *  Default: Enabled
 */
declare type FocusConfig = Partial<typeof DefaultFocusConfig> | null | false;
declare const DefaultDismissConfig: {
    enabled: boolean;
};
/**
 *  Auto close.
 *  Default: Enabled
 */
declare type DismissConfig = Partial<typeof DefaultDismissConfig> | null | false;
declare type AutoInteractionsOptions = {
    hover?: HoverConfig;
    click?: ClickConfig;
    focus?: FocusConfig;
    role?: RoleConfig;
    dismiss?: DismissConfig;
};
export declare type Options = AutoPositionOptions & AutoInteractionsOptions;
declare type AutoInteration<T extends HTMLElement, Y extends HTMLElement> = Omit<AutoPosition<T, Y>, '_context' | '_open'> & {
    open: boolean;
    getTriggerProps: (userProps?: React.HTMLProps<Element> | undefined) => Record<string, unknown>;
    getFloatProps: (userProps?: React.HTMLProps<HTMLElement> | undefined) => Record<string, unknown>;
};
/**
 * Wrap above useAutoPosition with interaction controls.
 * Based on the config updated open property
 * @param config Options to modify the behaviour
 */
export declare const useAutoInteractions: <T extends HTMLElement = HTMLElement, Y extends HTMLElement = HTMLElement>(config?: Partial<Options>) => AutoInteration<T, Y>;
export default useAutoInteractions;
